AnyProvider

Enum AnyProvider 

pub enum AnyProvider {
    JsonRpcHttp(JsonRpcClient<HttpTransport>),
    SequencerGateway(SequencerGatewayProvider),
}
A convenient Box-able type that implements the Provider trait. This can be useful when you want to accept any built-in provider implementation from the library in your appliation, since the Provider trait itself cannot be Box-ed due to the use of associated type.

A recommended pattern is to make your business logic code (e.g. functions) generic over the Provider trait, while using this AnyProvider type for bootstrapping your application.

NOTE: This type was introduced when Provider was not Box-able. It should be reviewed whether it’s still needed anymore.

Variants



JsonRpcHttp(JsonRpcClient<HttpTransport>)

JSON-RPC provider.



SequencerGateway(SequencerGatewayProvider)

Sequencer gateway provider.